# Generated by roxygen2: do not edit by hand

S3method("[",levelsMap)
S3method("[",listLevelsMap)
S3method("mapLevels<-",data.frame)
S3method("mapLevels<-",default)
S3method("mapLevels<-",list)
S3method(NAToUnknown,data.frame)
S3method(NAToUnknown,default)
S3method(NAToUnknown,factor)
S3method(NAToUnknown,list)
S3method(c,levelsMap)
S3method(c,listLevelsMap)
S3method(c,object_sizes)
S3method(format,object_sizes)
S3method(isUnknown,POSIXlt)
S3method(isUnknown,data.frame)
S3method(isUnknown,default)
S3method(isUnknown,list)
S3method(isUnknown,matrix)
S3method(mapLevels,character)
S3method(mapLevels,data.frame)
S3method(mapLevels,default)
S3method(mapLevels,factor)
S3method(mapLevels,list)
S3method(plot,summaryAlphaPart)
S3method(print,AlphaPart)
S3method(print,levelsMap)
S3method(print,listLevelsMap)
S3method(print,object_sizes)
S3method(print,plotSummaryAlphaPart)
S3method(print,summaryAlphaPart)
S3method(savePlot,default)
S3method(savePlot,plotSummaryAlphaPart)
S3method(sort,levelsMap)
S3method(summary,AlphaPart)
S3method(unique,levelsMap)
S3method(unknownToNA,data.frame)
S3method(unknownToNA,default)
S3method(unknownToNA,factor)
S3method(unknownToNA,list)
S3method(write.csv,AlphaPart)
S3method(write.csv,summaryAlphaPart)
export("mapLevels<-")
export(.checkLevelsMap)
export(.checkListLevelsMap)
export(.isCharacterMap)
export(.unknownList)
export(.unlistLevelsMap)
export(AlphaPart)
export(AlphaPartSubset)
export(AlphaPartSum)
export(NAToUnknown)
export(as.levelsMap)
export(as.listLevelsMap)
export(as.object_sizes)
export(centerPop)
export(getScale)
export(is.levelsMap)
export(is.listLevelsMap)
export(is.object_sizes)
export(isUnknown)
export(mapLevels)
export(object.size)
export(pedFixBirthYear)
export(pedSetBase)
export(sEBV)
export(savePlot)
export(unknownToNA)
export(write.csv)
import(ggplot2)
importFrom(Rcpp,sourceCpp)
importFrom(directlabels,direct.label)
importFrom(directlabels,last.qp)
importFrom(dplyr,do)
importFrom(dplyr,group_by)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.off)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(pedigree,orderPed)
importFrom(reshape,melt)
importFrom(stats,aggregate)
importFrom(stats,confint)
importFrom(stats,cov)
importFrom(stats,lm)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(tibble,is_tibble)
importFrom(utils,head)
importFrom(utils,str)
importFrom(utils,tail)
importFrom(utils,write.csv2)
useDynLib(AlphaPart, .registration = TRUE)
